<?php
namespace Epygi\Shell\Command;

use Epygi;

class CheckSAM
{
    /**
     * feature:
     *    user
     *    gui pass
     */
    const BIN_SAMSON = '/bin/samson';

	/**
	* 	
	*/
    public static function samCheck($user, $passwd)
    {
        $cmd = new Epygi\Shell\Command(self::BIN_SAMSON);
        $cmd->arg($user);
        $cmd->arg($passwd);

        // run
        try {
            if ($cmd->execute() == 0) {
                if (count($cmd->data) > 0)
                    return explode(':', $cmd->data[0]);
            }
        }
        catch(\Exception $e) {

        }
        return array(-1,-1,0);
    }

    public static function decryptPass($encryptedpasswd, &$passwd)
    {
        $cmd = new Epygi\Shell\Command(self::BIN_SAMSON);
        $cmd->arg('-de');
        $cmd->arg($encryptedpasswd);

        // run
        try {
            if ($cmd->execute() == 0) {
		$passwd = $cmd->data[0];
                return 0;
            }
        }
        catch(\Exception $e) {

        }
        return -1;
    }
    
    public static function samGet2faKey($user)
    {
        $cmd = new Epygi\Shell\Command(self::BIN_SAMSON);
        $cmd->arg($user);
        $cmd->arg("-rk");

        // run
        try {
            if ($cmd->execute() == 0) {
	    	return $cmd->data[0];
            }
        }
        catch(\Exception $e) {

        }
        return '';
    }
} 